#!/bin/sh
#
# getPatchLevel - Display highest level of specified Solaris patch IDs
#
# Copyright (c) 2005 Occam's Razor. All rights reserved.
#
# See the LICENSE file distributed with this code for restrictions on its use
# and further distribution.
# Original distribution available at <http://www.occam.com/tools/>.
#
# $Id: getPatchLevel.sh,v 1.1 2006/03/19 00:05:35 leonvs Exp $
#

PATH=/bin:/usr/bin

usage () {
	echo "$VERSION
usage:	$progname patchID [patchID]..." >&2
	exit 2
}

setup () {
	progname=`basename $0`

	VERSION="$progname 1.1"

	# Need at least one argument.
	[ $# -ge 1 ] || usage

	patches=$*

	os=`uname -s`
	case $os in
		SunOS)	;;
		*)	error "This command is only useful on Solaris.";;
	esac

	listCmd="showrev -p | awk '{ print $2 }' | grep"
}

isValidPatchID () {
	patchID=$1

	# Patch ID should be six decimal digits. Strip that, and if anything is
	# left, then the format wasn't right.
	patchID=`echo $patchID | sed 's/^[0-9]\{6\}$//'`

	return `[ "X$patchID" = "X" ]`
}

error () {
	msg=$*
	echo "$progname: $msg" >&2
	cleanup 2
}

cleanup () {
	status=$1
	exit $status
}

setup $*
for patch in $patches; do
	# Strip "-NN" from end of patch ID, if it's there.
	patch=`echo $patch | sed 's/-[0-9]\{2\}$//'`
	isValidPatchID $patch || error "$patch is not a valid patch ID."
	showrev -p | cut -d" " -f2 | grep $patch | sort -n | tail -1
done
cleanup 0
